﻿local _CommonFunctions, StoneGateSetPrefix, CommonWindowPrefix, StoneGateSetPrefixWhiteFloor, CommonDoorPrefix = ...

_CommonFunctions:registerEnumValue ("BUILDING_PART_TYPE", "EXTENSION")
_CommonFunctions:registerEnumValue ("BUILDING_PART_TYPE", "DECORATION")
_optionAccessNodeType = "STONEGATEACCESS"
_CommonFunctions:registerEnumValue ("ATTACH_NODE_TYPE", _optionAccessNodeType)
_optionPinionNodeType = "STONEGATEPINION"
_CommonFunctions:registerEnumValue ("ATTACH_NODE_TYPE", _optionPinionNodeType)

-- register specific housing function
function registerFunctionHouse(_assetPrefix, _assetId, _lvl)
        function houseStatusList()
            function houseStatus(_desirabilityLevel)
                return {
	            DataType = "HOUSE_STATUS",
	            RequiredDesirability = _desirabilityLevel,
	            ResourceGenerated = "HOUSING_LEVEL_" .. _lvl,
	            HouseDensityPartList = { _assetPrefix .. "_" .. _assetId .. "_PART" }
                }
            end
            if _lvl == "1" then
                return {
	            houseStatus(DESIRABILITY_LEVEL.LOW),
	            houseStatus(DESIRABILITY_LEVEL.HIGH)
	        }
            end
            if _lvl == "2" then
	        return {
	            houseStatus(DESIRABILITY_LEVEL.AVERAGE),
	            houseStatus(DESIRABILITY_LEVEL.VERY_HIGH)
	        }
            end
            return nil
        end

        _CommonFunctions:register({
	    DataType= "HOUSE_SETUP",
	    Id = _assetPrefix .. "_" .. _assetId .. "_HOUSING_LVL" .. _lvl .. "_SETUP",
	    HouseStatusList = houseStatusList()
        })
        _CommonFunctions:register({
	    DataType = "BUILDING_FUNCTION_HOUSE",
	    Id = _assetPrefix .. "_" .. _assetId .. "_HOUSING_LVL" .. _lvl .. "_FUNCTION",
            Name = _assetPrefix .. "_BUILDING_FUNCTION_HOUSING_LVL" .. _lvl .. "_NAME",
	    RelatedZone = "RESIDENTIAL",
	    RelatedDesirability = "DESIRABILITY_RESIDENTIAL",
	    AssetHouseSetup =  _assetPrefix .. "_" .. _assetId .. "_HOUSING_LVL" .. _lvl .. "_SETUP",
        })
        return _assetPrefix .. "_" .. _assetId .. "_HOUSING_LVL" .. _lvl .. "_FUNCTION"
end

-- Register the stone gate set material list

function configureMaterialSet(_colorRoof, _colorWall, _colorCrenellation, _colorBasement, _colorFloorGround, _colorFrame, _defaultMaterial, _custom)
    if _custom then
        return  {
                SetName = StoneGateSetPrefix .. "_CUSTOM_THEME",
                MaterialList =  configureMaterialList(_colorRoof, _colorWall, _colorCrenellation, _colorBasement, _colorFloorGround, _colorFrame, _defaultMaterial)
        }
    end
    
    return  {
                SetName = StoneGateSetPrefix .. "_" .. _colorRoof ..  "_" .. _colorWall,
                MaterialList =  configureMaterialList(_colorRoof, _colorWall, _colorCrenellation, _colorBasement, _colorFloorGround, _colorFrame, _defaultMaterial)
   }
end

function configureMaterialList(_colorRoof, _colorWall, _colorCrenellation, _colorBasement, _colorFloorGround, _colorFrame, _defaultMaterial)
    function configureWindowRoofMaterial(_core)
        if _defaultMaterial then
            return CommonWindowPrefix .. "_" .. _core .. "_" .. _colorRoof .. "_ROOF_MATERIAL"
        else
            return CommonWindowPrefix .. "_DECORATION_" .. _colorRoof .. "_ROOF_MATERIAL"
        end
    end
    function configureWindowWallMaterial(_core)
        if _defaultMaterial then
            return CommonWindowPrefix .. "_" .. _core .. "_" .. _colorWall .. "_WALL_MATERIAL"
        else
            return CommonWindowPrefix .. "_DECORATION_" .. _colorWall .. "_WALL_MATERIAL"
        end
    end
    function configureWindowFrameMaterial(_core)
        if _defaultMaterial then
            return CommonWindowPrefix .. "_" .. _core .. "_" .. _colorFrame .. "_FRAME_MATERIAL"
        else
            return CommonWindowPrefix .. "_DECORATION_" .. _colorFrame .. "_FRAME_MATERIAL"
        end
    end
    function configureSimpleRoofMaterial(_core)
        if _defaultMaterial then
            return StoneGateSetPrefix .. "_" .. _core .. "_" .. _colorRoof .. "_ROOF_MATERIAL"
        else
            return CommonWindowPrefix .. "_DECORATION_" .. _colorRoof .. "_ROOF_MATERIAL"
        end
    end
    function configurePointedRoofMaterial(_core)
        if _defaultMaterial then
            return StoneGateSetPrefix .. "_POINTED_" .. _core .. "_" .. _colorRoof .. "_ROOF_MATERIAL"
        else
            return CommonWindowPrefix .. "_DECORATION_" .. _colorRoof .. "_ROOF_MATERIAL"
        end
    end
    function configureRoofOverMachicolationsMaterial(_core)
        if _defaultMaterial then
            return StoneGateSetPrefix .. "_MACHICOLATION_" .. _core .. "_" .. _colorRoof .. "_ROOF_MATERIAL"
        else
            return CommonWindowPrefix .. "_DECORATION_" .. _colorRoof .. "_ROOF_MATERIAL"
        end
    end
    function configureWallMaterial(_core)
        if _defaultMaterial then
            return StoneGateSetPrefix .. "_" .. _core .. "_" .. _colorWall .. "_WALL_MATERIAL"
        else
            return CommonWindowPrefix .. "_DECORATION_" .. _colorWall .. "_WALL_MATERIAL"
        end
    end
    function configureFrameMaterial(_core)
        if _defaultMaterial then
            return StoneGateSetPrefix .. "_" .. _core .. "_" .. _colorFrame .. "_FRAME_MATERIAL"
        else
            return CommonWindowPrefix .. "_DECORATION_" .. _colorFrame .. "_FRAME_MATERIAL"
        end
    end
    function configureCrenellationMaterial(_core)
        if _defaultMaterial then
            return StoneGateSetPrefix .. "_" .. _core .. "_" .. _colorCrenellation .. "_CRENELLATION_MATERIAL"
        else
            return CommonWindowPrefix .. "_DECORATION_" .. _colorCrenellation .. "_CRENELLATION_MATERIAL"
        end
    end
    function configureBasementMaterial(_core)
        if _defaultMaterial then
            return StoneGateSetPrefix .. "_" .. _core .. "_" .. _colorBasement .. "_BASEMENT_MATERIAL"
        else
            return CommonWindowPrefix .. "_DECORATION_" .. _colorBasement .. "_BASEMENT_MATERIAL"
        end
    end
    function configureFloorGroundMaterial(_core)
        if _defaultMaterial then
            return StoneGateSetPrefix .. "_" .. _core .. "_" .. _colorFloorGround .. "_FLOOR_GROUND_MATERIAL"
        else
            return CommonWindowPrefix .. "_DECORATION_" .. _colorFloorGround .. "_FLOOR_GROUND_MATERIAL"
        end
    end
    
    return {
                    -- from Windows Decoration mod
                    configureWindowRoofMaterial("STONE_WINDOW"),
-- currently not used                    configureWindowRoofMaterial("WOODEN_DOOR"),
                    configureWindowRoofMaterial("WOODEN_WINDOW"),
                    configureWindowRoofMaterial("WOODEN_ENTRANCE"),
                    configureWindowWallMaterial("STONE_DECORATION"),
                    configureWindowWallMaterial("STONE_BUTTRESS"),
                    configureWindowFrameMaterial("STONE_DECORATION"),
                    configureWindowFrameMaterial("STONE_DECORATION3"),
                    configureWindowFrameMaterial("STONE_DOORS"),
                    configureWindowFrameMaterial("CORNER"),
                    configureWindowFrameMaterial("STAINED_GLASS"),
                    -- simple roofs
                    configureSimpleRoofMaterial("MAIN"),
                    configureSimpleRoofMaterial("KEEP"),
                    configureSimpleRoofMaterial("SST"),
                    configureSimpleRoofMaterial("SGATE"),
                    configureSimpleRoofMaterial("A45"),
                    configureSimpleRoofMaterial("OTOWER"),
                    configureSimpleRoofMaterial("CIRCULAR"),
                    configureSimpleRoofMaterial("SCT"),
                    -- pointed roofs
                    configurePointedRoofMaterial("MAIN"),
                    configurePointedRoofMaterial("KEEP"),
                    configurePointedRoofMaterial("SST"),
                    configurePointedRoofMaterial("OTOWER"),
                    configurePointedRoofMaterial("CIRCULAR"),
                    configurePointedRoofMaterial("SCT"),
                    configurePointedRoofMaterial("SGATE"),
                    configurePointedRoofMaterial("A45"),
                    -- roofs over machicolations
                    configureRoofOverMachicolationsMaterial("MAIN"),
                    configureRoofOverMachicolationsMaterial("KEEP"),
                    configureRoofOverMachicolationsMaterial("SST"),
                    configureRoofOverMachicolationsMaterial("SGATE"),
                    configureRoofOverMachicolationsMaterial("SGATE2"),
                    configureRoofOverMachicolationsMaterial("A45"),
                    configureRoofOverMachicolationsMaterial("OTOWER"),
                    configureRoofOverMachicolationsMaterial("CIRCULAR"),
                    configureRoofOverMachicolationsMaterial("SCT"),
                    -- wall
                    configureWallMaterial("OVER_HANGING"),
                    configureWallMaterial("A45"),
                    configureWallMaterial("CIRCULAR"),
                    configureWallMaterial("KEEP"),
                    configureWallMaterial("LARGE_GATE"),
                    configureWallMaterial("MAIN"),
                    configureWallMaterial("OTOWER"),
                    configureWallMaterial("SCT"),
                    configureWallMaterial("SGATE"),
                    configureWallMaterial("SST"),
                    configureWallMaterial("RAMPART_SST"), -- wall parts from the stairs
                    configureWallMaterial("BRIDGE_SST"),
                    configureWallMaterial("DECORATIONS_PINION"),
                    configureWallMaterial("DRAWBRIDGE_A"),
                    configureWallMaterial("MACHICOLATION_KEEP"),
                    configureWallMaterial("MACHICOLATION_MAIN"),
                    configureWallMaterial("MACHICOLATION_SST"),
                    configureWallMaterial("MACHICOLATION_SGATE"),
                    configureWallMaterial("MACHICOLATION_A45"),
                    configureWallMaterial("MACHICOLATION_OTOWER"),
                    configureWallMaterial("MACHICOLATION_CIRCULAR"),
                    configureWallMaterial("MACHICOLATION_SCT"),
                    configureWallMaterial("POINTED_ROOFS_PINION"),
                    -- crenellation
                    configureCrenellationMaterial("RAMPART_A45"),
                    configureCrenellationMaterial("RAMPART_CIRCULAR"),
                    configureCrenellationMaterial("RAMPART_KEEP"),
                    configureCrenellationMaterial("RAMPART_MAIN"),
                    configureCrenellationMaterial("RAMPART_OTOWER"),
                    configureCrenellationMaterial("RAMPART_SCT"),
                    configureCrenellationMaterial("SGATE"),
                    configureCrenellationMaterial("RAMPART_SST"),
                    configureCrenellationMaterial("HOARDING_A45"),
                    configureCrenellationMaterial("HOARDING_CIRCULAR"),
                    configureCrenellationMaterial("HOARDING_OTOWER"),
                    configureCrenellationMaterial("HOARDING_S3"),
                    configureCrenellationMaterial("HOARDING_EXTENSION_S3"),
                    configureCrenellationMaterial("HOARDING_S2"),
                    configureCrenellationMaterial("HOARDING_EXTENSION_S2"),
                    configureCrenellationMaterial("HOARDING_S1"),
                    configureCrenellationMaterial("HOARDING_SGATE"),
                    configureCrenellationMaterial("HOARDING_SGATE2"),
                    configureCrenellationMaterial("MACHICOLATION_KEEP"),
                    configureCrenellationMaterial("MACHICOLATION_CRENATION"),
                    configureCrenellationMaterial("MACHICOLATION_MAIN"),
                    configureCrenellationMaterial("MACHICOLATION_SST"),
                    configureCrenellationMaterial("MACHICOLATION_SGATE"),
                    configureCrenellationMaterial("MACHICOLATION_SGATE2"),
                    configureCrenellationMaterial("MACHICOLATION_A45"),
                    configureCrenellationMaterial("MACHICOLATION_OTOWER"),
                    configureCrenellationMaterial("MACHICOLATION_CIRCULAR"),
                    configureCrenellationMaterial("MACHICOLATION_SCT"),
                    -- basement
                    configureBasementMaterial("MAIN"),
                    configureBasementMaterial("KEEP"),
                    configureBasementMaterial("OTOWER"),
                    configureBasementMaterial("CIRCULAR"),
                    configureBasementMaterial("SST"),
                    -- floor ground
                    configureFloorGroundMaterial("SST"),
                    configureFloorGroundMaterial("RAMPART_SST"), -- ground parts from the stairs
                    configureFloorGroundMaterial("BRIDGE_SST"),
                    configureFloorGroundMaterial("MACHICOLATION_SST"),
                    configureFloorGroundMaterial("KEEP"),
                    configureFloorGroundMaterial("MACHICOLATION_KEEP"),
                    configureFloorGroundMaterial("MAIN"),
                    configureFloorGroundMaterial("MACHICOLATION_MAIN"),
                    configureFloorGroundMaterial("A45"),
                    configureFloorGroundMaterial("MACHICOLATION_A45"),
                    configureFloorGroundMaterial("CIRCULAR"),
                    configureFloorGroundMaterial("MACHICOLATION_CIRCULAR"),
                    configureFloorGroundMaterial("OTOWER"),
                    configureFloorGroundMaterial("MACHICOLATION_OTOWER"),
                    configureFloorGroundMaterial("SCT"),
                    configureFloorGroundMaterial("MACHICOLATION_SCT"),
                    configureFloorGroundMaterial("SGATE"),
                    configureFloorGroundMaterial("MACHICOLATION_SGATE"),
                    configureFloorGroundMaterial("MACHICOLATION_SGATE2"),
                    configureFloorGroundMaterial("LARGE_GATE"),
                    -- frame
                    configureFrameMaterial("LARGE_GATE"),
                    configureFrameMaterial("SCT"),
                    configureFrameMaterial("SGATE"),
                    configureFrameMaterial("SST"),
                    configureFrameMaterial("DECORATIONS_DECORATION"),
                    configureFrameMaterial("DRAWBRIDGE_A"),
                    configureFrameMaterial("DRAWBRIDGE_B"),
                    configureFrameMaterial("DRAWBRIDGE_C"),
                    configureFrameMaterial("MACHICOLATION_KEEP"),
                    configureFrameMaterial("MACHICOLATION_MAIN"),
                    configureFrameMaterial("MACHICOLATION_SST"),
                    configureFrameMaterial("MACHICOLATION_SGATE"),
                    configureFrameMaterial("MACHICOLATION_SGATE2"),
                    configureFrameMaterial("MACHICOLATION_A45"),
                    configureFrameMaterial("MACHICOLATION_OTOWER"),
                    configureFrameMaterial("MACHICOLATION_CIRCULAR"),
                    configureFrameMaterial("MACHICOLATION_SCT"),
               
    }
end

function configureMaterialSetList(_configureMaterialSet)
    return {
            _configureMaterialSet("RED_TILE", "STONE_MANOR", "STONE_MANOR", "STONE_MANOR", "WHITE_STONE", "WHITE_STONE", true, false), -- default material
            _configureMaterialSet("BLUE_TILE", "STONE_MANOR", "STONE_MANOR", "STONE_MANOR", "WHITE_STONE", "WHITE_STONE", false, false),
            _configureMaterialSet("BROWN_TILE", "STONE_MANOR", "STONE_MANOR", "STONE_MANOR", "WHITE_STONE", "WHITE_STONE", false, false),
            _configureMaterialSet("LIGHT_GREY_TILE", "STONE_MANOR", "STONE_MANOR", "STONE_MANOR", "WHITE_STONE", "WHITE_STONE", false, false),
            _configureMaterialSet("DARK_GREY_TILE", "STONE_MANOR", "STONE_MANOR", "STONE_MANOR", "WHITE_STONE", "WHITE_STONE", false, false),
            _configureMaterialSet("RED_SHINGLE", "STONE_MANOR", "STONE_MANOR", "STONE_MANOR", "WHITE_STONE", "WHITE_STONE", false, false),
            _configureMaterialSet("BLUE_SHINGLE", "STONE_MANOR", "STONE_MANOR", "STONE_MANOR", "WHITE_STONE", "WHITE_STONE", false, false),
            _configureMaterialSet("BROWN_SHINGLE", "STONE_MANOR", "STONE_MANOR", "STONE_MANOR", "WHITE_STONE", "WHITE_STONE", false, false),
            _configureMaterialSet("YELLOW_SHINGLE", "STONE_MANOR", "STONE_MANOR", "STONE_MANOR", "WHITE_STONE", "WHITE_STONE", false, false),
            _configureMaterialSet("GREEN_SHINGLE", "STONE_MANOR", "STONE_MANOR", "STONE_MANOR", "WHITE_STONE", "WHITE_STONE", false, false ),
            _configureMaterialSet("WOODEN_MANOR", "STONE_MANOR", "STONE_MANOR", "STONE_MANOR", "WHITE_STONE", "WHITE_STONE", false, false),
            _configureMaterialSet("STONE_MANOR", "STONE_MANOR", "STONE_MANOR", "STONE_MANOR", "WHITE_STONE", "WHITE_STONE", false, false),
            _configureMaterialSet("BROWN_MONASTERY", "BROWN_MONASTERY", "BROWN_MONASTERY", "BROWN_MONASTERY", "WHITE_STONE", "WHITE_STONE", false, false),
            _configureMaterialSet("BLUE_MONASTERY", "BLUE_MONASTERY", "BLUE_MONASTERY", "BLUE_MONASTERY", "WHITE_STONE", "WHITE_STONE", false, false),
            _configureMaterialSet("PURPLE_MONASTERY", "PURPLE_MONASTERY", "PURPLE_MONASTERY", "PURPLE_MONASTERY", "WHITE_STONE", "WHITE_STONE", false, false),
            _configureMaterialSet("WOODEN_MANOR", "RED_STONE", "RED_STONE", "RED_STONE", "RED_STONE", "WHITE_STONE", false, false),
            _configureMaterialSet("RED_SHINGLE", "GIANT_GATE", "GIANT_GATE", "GIANT_GATE", "WHITE_STONE", "WHITE_STONE", false, false),
            _configureMaterialSet("STRAW", "WHITE_CHALK", "WHITE_CHALK", "STONE_MANOR", "WHITE_STONE", "WHITE_STONE", false, false),
            _configureMaterialSet("BROWN_MONASTERY", "WHITE_CHALK", "WHITE_CHALK", "STONE_MANOR", "WHITE_STONE", "WHITE_STONE", false, false),
            _configureMaterialSet("RED_TILE", "SAND_STONE", "SAND_STONE", "SAND_STONE", "WHITE_STONE", "WHITE_STONE", false, false),
            _configureMaterialSet("BROWN_TILE", "SAND_STONE", "SAND_STONE", "SAND_STONE", "WHITE_STONE", "WHITE_STONE", false, false),
            _configureMaterialSet("STRAW", "WOOD", "WHITE_CHALK", "STONE_MANOR", "WHITE_STONE", "WOOD", false, false),
            _configureMaterialSet("DARK_GREY_TILE", "AMERICAN_SHINGLE", "WHITE_CHALK", "STONE_MANOR", "WHITE_STONE", "WHITE_CHALK", false, false),
            _configureMaterialSet(_CustomRoofMaterial,
                                  _CustomWallMaterial,
                                  _CustomCrenellationMaterial,
                                  _CustomBasementMaterial,
                                  _CustomGroundMaterial,
                                  _CustomFrameMaterial,
                                  false, true),
    }
end

function configureBuildingPartSetList()
    return {
		{
			Name = StoneGateSetPrefix .. "_MAIN_PARTSETLIST_NAME",
	                BuildingPartList = {
		            StoneGateSetPrefix .. "_MAIN_ROOT_PART",
		            StoneGateSetPrefix .. "_MAIN_ROOTP_PART",
		            StoneGateSetPrefix .. "_MAIN_ROOTHALFWHITE_PART",
		            StoneGateSetPrefix .. "_MAIN_ROOF_D_PART", -- Closed roof
		            StoneGateSetPrefix .. "_MAIN_ROOF_A_PART", -- Opened roof
		            StoneGateSetPrefix .. "_MAIN_ROOF_B_PART", -- half opened roof 1
		            StoneGateSetPrefix .. "_MAIN_ROOF_E_PART", -- shed roof
		            StoneGateSetPrefix .. "_MAIN_ROOF_D30x_PART", -- Closed roof
		            StoneGateSetPrefix .. "_MAIN_ROOF_A30x_PART", -- Opened roof
		            StoneGateSetPrefix .. "_MAIN_ROOF_B30x_PART", -- half opened roof 1
		            StoneGateSetPrefix .. "_MAIN_ROOF_E30x_PART", -- shed roof
		            StoneGateSetPrefix .. "_MAIN_ROOF_E24x_PART", -- shed roof
		            StoneGateSetPrefix .. "_MAIN_ROOF_D60x_PART", -- Closed roof
		            StoneGateSetPrefix .. "_MAIN_ROOF_A60x_PART", -- Opened roof
		            StoneGateSetPrefix .. "_MAIN_ROOF_B60x_PART", -- half opened roof 1
		            StoneGateSetPrefix .. "_MAIN_ROOF_E60x_PART", -- shed roof
		            StoneGateSetPrefix .. "_MAIN_POINTED_ROOF_A_PART",
		            StoneGateSetPrefix .. "_MAIN_POINTED_ROOF_B_PART",
		            StoneGateSetPrefix .. "_MAIN_POINTED_ROOF_E_PART",
		            StoneGateSetPrefix .. "_MAIN_RAMPART_D_PART", -- Closed rampart
		            StoneGateSetPrefix .. "_MAIN_RAMPART_A_PART", -- Opened rampart
		            StoneGateSetPrefix .. "_MAIN_RAMPART_B_PART",  -- half opened rampart 1
		            StoneGateSetPrefix .. "_WFMAIN_A_PART",
		            StoneGateSetPrefix .. "_WFMAIN_B_PART",
		            StoneGateSetPrefix .. "_WFMAIN_C_PART",
		            StoneGateSetPrefix .. "_WFMAIN_D_PART",
		            StoneGateSetPrefixWhiteFloor .. "_WFMAIN_A_PART",
		            StoneGateSetPrefixWhiteFloor .. "_WFMAIN_B_PART",
		            StoneGateSetPrefixWhiteFloor .. "_WFMAIN_C_PART",
                        }
                },
		{
			Name = StoneGateSetPrefix .. "_KEEP_PARTSETLIST_NAME",
	                BuildingPartList = {
		            StoneGateSetPrefix .. "_KEEP_ROOT_PART",
		            StoneGateSetPrefix .. "_KEEP_ROOTP_PART",
		            StoneGateSetPrefix .. "_KEEP_ROOTHALFWHITE_PART",
		            StoneGateSetPrefix .. "_KEEPH_ROOTP_PART",
		            StoneGateSetPrefix .. "_KEEPI_ROOTP_PART",
		            StoneGateSetPrefix .. "_KEEPJ_ROOTP_PART",
		            StoneGateSetPrefix .. "_KEEPK_ROOTP_PART",
		            StoneGateSetPrefix .. "_KEEPL_ROOTP_PART",
		            StoneGateSetPrefix .. "_LGATE_ROOT_PART",
		            StoneGateSetPrefix .. "_LGATE_ROOTP_PART",
		            StoneGateSetPrefix .. "_LGATE_2_ROOT_PART",
		            StoneGateSetPrefix .. "_LGATE_2_ROOTP_PART",
		            StoneGateSetPrefix .. "_LGATE_3_ROOT_PART",
		            StoneGateSetPrefix .. "_LGATE_3_ROOTP_PART",
		            StoneGateSetPrefix .. "_LGATE_4_ROOT_PART",
		            StoneGateSetPrefix .. "_LGATE_4_ROOTP_PART",
		            StoneGateSetPrefix .. "_KEEP_ROOF_C_PART", -- Closed roof
		            StoneGateSetPrefix .. "_KEEP_ROOF_D_PART", -- 1 side opened
		            StoneGateSetPrefix .. "_KEEP_ROOF_B_PART", -- 2 opposite sides opened
		            StoneGateSetPrefix .. "_KEEP_ROOF_E_PART", -- 2 adjacent sides opened
		            StoneGateSetPrefix .. "_KEEP_ROOF_A_PART", -- 3 sides opened
		            StoneGateSetPrefix .. "_KEEP_ROOF_F_PART", -- all sides opened
		            StoneGateSetPrefix .. "_KEEP_ROOF_G_PART", -- roof extension
		            StoneGateSetPrefix .. "_KEEP_ROOF_H_PART", -- roof extension
		            StoneGateSetPrefix .. "_DECORATION_PINION_B_PART",
		            StoneGateSetPrefix .. "_DECORATION_PINION_C_PART", -- simple pinion
		            StoneGateSetPrefix .. "_DECORATION_PINION_G_PART", -- simple stone pinion
		            StoneGateSetPrefix .. "_DECORATION_PINION_I_PART", -- simple full wodden pinion
		            StoneGateSetPrefix .. "_DECORATION_PINION_D_PART", -- simple pinion
		            StoneGateSetPrefix .. "_KEEP_ROOF_I_PART", -- shed roof
		            StoneGateSetPrefix .. "_KEEP_ROOF_L_PART", -- shed roof with 2 adjacent sides opened
		            StoneGateSetPrefix .. "_KEEP_ROOF_J_PART", -- shed roof extension
		            StoneGateSetPrefix .. "_KEEP_ROOF_K_PART", -- shed roof extension
		            StoneGateSetPrefix .. "_DECORATION_PINION_LEFT_SHED_A_PART", -- left shed stone pinion
		            StoneGateSetPrefix .. "_DECORATION_PINION_RIGHT_SHED_A_PART", -- right shed stone pinion
		            StoneGateSetPrefix .. "_DECORATION_PINION_LEFT_SHED_B_PART", -- left shed cream pinion
		            StoneGateSetPrefix .. "_DECORATION_PINION_RIGHT_SHED_B_PART", -- right shed cream pinion
		            StoneGateSetPrefix .. "_DECORATION_PINION_LEFT_SHED_D_PART", -- left shed full wooden pinion
		            StoneGateSetPrefix .. "_DECORATION_PINION_RIGHT_SHED_D_PART", -- right shed full wooden pinion
		            StoneGateSetPrefix .. "_DECORATION_PINION_LEFT_SHED_C_PART", -- left pinion for shed roof
		            StoneGateSetPrefix .. "_DECORATION_PINION_RIGHT_SHED_C_PART", -- right pinion for shed roof
		            StoneGateSetPrefix .. "_KEEP_RAMPART_C_PART", -- Closed roof
		            StoneGateSetPrefix .. "_KEEP_RAMPART_D_PART", -- 1 side opened
		            StoneGateSetPrefix .. "_KEEP_RAMPART_B_PART", -- 2 opposite sides opened
		            StoneGateSetPrefix .. "_KEEP_RAMPART_E_PART", -- 2 adjacent sides opened
		            StoneGateSetPrefix .. "_KEEP_RAMPART_A_PART", -- 3 sides opened
		            StoneGateSetPrefix .. "_KEEP_RAMPART_F_PART", -- all sides opened
		            StoneGateSetPrefix .. "_WFKEEP_A_PART",
		            StoneGateSetPrefix .. "_WFKEEP_B_PART",
		            StoneGateSetPrefix .. "_WFKEEP_C_PART",
		            StoneGateSetPrefix .. "_WFKEEP_D_PART",
		            StoneGateSetPrefixWhiteFloor .. "_WFKEEP_A_PART",
		            StoneGateSetPrefixWhiteFloor .. "_WFKEEP_B_PART",
		            StoneGateSetPrefixWhiteFloor .. "_WFKEEP_C_PART",
                        }
                },
		{
			Name = StoneGateSetPrefix .. "_KEEP_POINTED_PARTSETLIST_NAME",
	                BuildingPartList = {
		            StoneGateSetPrefix .. "_KEEP_POINTED_ROOF_A_PART",
		            StoneGateSetPrefix .. "_KEEP_POINTED_ROOF_B_PART",
		            StoneGateSetPrefix .. "_KEEP_POINTED_ROOF_D_PART",
		            StoneGateSetPrefix .. "_KEEP_POINTED_ROOF_E_PART",
		            StoneGateSetPrefix .. "_KEEP_POINTED_ROOF_F_PART",
		            StoneGateSetPrefix .. "_KEEP_POINTED_ROOF_G_PART",
		            StoneGateSetPrefix .. "_KEEP_POINTED_ROOF_H_PART", -- roof extension
		            StoneGateSetPrefix .. "_KEEP_POINTED_ROOF_I_PART", -- roof extension
		            StoneGateSetPrefix .. "_DECORATION_POINTED_PINION_C_PART", -- pointed pinion
		            StoneGateSetPrefix .. "_DECORATION_POINTED_PINION_G_PART", -- pointed stone pinion
		            StoneGateSetPrefix .. "_DECORATION_POINTED_PINION_I_PART", -- pointed full wooden pinion
		            StoneGateSetPrefix .. "_DECORATION_POINTED_PINION_D_PART", -- pointed pinion
                        }
                },
		{
			Name = StoneGateSetPrefix .. "_KEEP30_PARTSETLIST_NAME",
	                BuildingPartList = {
		            StoneGateSetPrefix .. "_KEEP_ROOF_C30x_PART", -- Closed roof
		            StoneGateSetPrefix .. "_KEEP_ROOF_D30x_PART", -- 1 side opened
		            StoneGateSetPrefix .. "_KEEP_ROOF_B30x_PART", -- 2 opposite sides opened
		            StoneGateSetPrefix .. "_KEEP_ROOF_E30x_PART", -- 2 adjacent sides opened
		            StoneGateSetPrefix .. "_KEEP_ROOF_A30x_PART", -- 3 sides opened
		            StoneGateSetPrefix .. "_KEEP_ROOF_F30x_PART", -- all sides opened
		            StoneGateSetPrefix .. "_KEEP_ROOF_G30x_PART", -- roof extension
		            StoneGateSetPrefix .. "_KEEP_ROOF_H30x_PART", -- roof extension
		            StoneGateSetPrefix .. "_DECORATION_PINION_C30x_PART", -- simple pinion
		            StoneGateSetPrefix .. "_DECORATION_PINION_G30x_PART", -- simple stone pinion
		            StoneGateSetPrefix .. "_DECORATION_PINION_I30x_PART", -- simple full wodden pinion
		            StoneGateSetPrefix .. "_DECORATION_PINION_D30x_PART", -- simple pinion
		            StoneGateSetPrefix .. "_KEEP_ROOF_I30x_PART", -- shed roof
		            StoneGateSetPrefix .. "_KEEP_ROOF_L30x_PART", -- shed roof with 2 adjacent sides opened
		            StoneGateSetPrefix .. "_KEEP_ROOF_J30x_PART", -- shed roof extension
		            StoneGateSetPrefix .. "_KEEP_ROOF_K30x_PART", -- shed roof extension
		            StoneGateSetPrefix .. "_DECORATION_PINION_LEFT_SHED_A30x_PART", -- left shed stone pinion
		            StoneGateSetPrefix .. "_DECORATION_PINION_RIGHT_SHED_A30x_PART", -- right shed stone pinion
		            StoneGateSetPrefix .. "_DECORATION_PINION_LEFT_SHED_B30x_PART", -- left shed cream pinion
		            StoneGateSetPrefix .. "_DECORATION_PINION_RIGHT_SHED_B30x_PART", -- right shed cream pinion
		            StoneGateSetPrefix .. "_DECORATION_PINION_LEFT_SHED_D30x_PART", -- left shed full wooden pinion
		            StoneGateSetPrefix .. "_DECORATION_PINION_RIGHT_SHED_D30x_PART", -- right shed full wooden pinion
		            StoneGateSetPrefix .. "_DECORATION_PINION_LEFT_SHED_C30x_PART", -- left pinion for shed roof
		            StoneGateSetPrefix .. "_DECORATION_PINION_RIGHT_SHED_C30x_PART", -- right pinion for shed roof
		            StoneGateSetPrefix .. "_KEEP_ROOF_I24x_PART", -- shed roof
		            StoneGateSetPrefix .. "_KEEP_ROOF_L24x_PART", -- shed roof with 2 adjacent sides opened
		            StoneGateSetPrefix .. "_KEEP_ROOF_J24x_PART", -- shed roof extension
		            StoneGateSetPrefix .. "_KEEP_ROOF_K24x_PART", -- shed roof extension
		            StoneGateSetPrefix .. "_DECORATION_PINION_LEFT_SHED_A24x_PART", -- left shed stone pinion
		            StoneGateSetPrefix .. "_DECORATION_PINION_RIGHT_SHED_A24x_PART", -- right shed stone pinion
		            StoneGateSetPrefix .. "_DECORATION_PINION_LEFT_SHED_B24x_PART", -- left shed cream pinion
		            StoneGateSetPrefix .. "_DECORATION_PINION_RIGHT_SHED_B24x_PART", -- right shed cream pinion
		            StoneGateSetPrefix .. "_DECORATION_PINION_LEFT_SHED_D24x_PART", -- left shed full wooden pinion
		            StoneGateSetPrefix .. "_DECORATION_PINION_RIGHT_SHED_D24x_PART", -- right shed full wooden pinion
		            StoneGateSetPrefix .. "_DECORATION_PINION_LEFT_SHED_C24x_PART", -- left pinion for shed roof
		            StoneGateSetPrefix .. "_DECORATION_PINION_RIGHT_SHED_C24x_PART", -- right pinion for shed roof
                        }
                },
		{
			Name = StoneGateSetPrefix .. "_KEEP60_PARTSETLIST_NAME",
	                BuildingPartList = {
		            StoneGateSetPrefix .. "_KEEP_ROOF_C60x_PART", -- Closed roof
		            StoneGateSetPrefix .. "_KEEP_ROOF_D60x_PART", -- 1 side opened
		            StoneGateSetPrefix .. "_KEEP_ROOF_B60x_PART", -- 2 opposite sides opened
		            StoneGateSetPrefix .. "_KEEP_ROOF_E60x_PART", -- 2 adjacent sides opened
		            StoneGateSetPrefix .. "_KEEP_ROOF_A60x_PART", -- 3 sides opened
		            StoneGateSetPrefix .. "_KEEP_ROOF_F60x_PART", -- all sides opened
		            StoneGateSetPrefix .. "_KEEP_ROOF_G60x_PART", -- roof extension
		            StoneGateSetPrefix .. "_KEEP_ROOF_H60x_PART", -- roof extension
		            StoneGateSetPrefix .. "_DECORATION_PINION_C60x_PART", -- simple pinion
		            StoneGateSetPrefix .. "_DECORATION_PINION_G60x_PART", -- simple stone pinion
		            StoneGateSetPrefix .. "_DECORATION_PINION_I60x_PART", -- simple full wodden pinion
		            StoneGateSetPrefix .. "_DECORATION_PINION_D60x_PART", -- simple pinion
		            StoneGateSetPrefix .. "_KEEP_ROOF_I60x_PART", -- shed roof
		            StoneGateSetPrefix .. "_KEEP_ROOF_L60x_PART", -- shed roof with 2 adjacent sides opened
		            StoneGateSetPrefix .. "_KEEP_ROOF_J60x_PART", -- shed roof extension
		            StoneGateSetPrefix .. "_KEEP_ROOF_K60x_PART", -- shed roof extension
		            StoneGateSetPrefix .. "_DECORATION_PINION_LEFT_SHED_A60x_PART", -- left shed stone pinion
		            StoneGateSetPrefix .. "_DECORATION_PINION_RIGHT_SHED_A60x_PART", -- right shed stone pinion
		            StoneGateSetPrefix .. "_DECORATION_PINION_LEFT_SHED_B60x_PART", -- left shed cream pinion
		            StoneGateSetPrefix .. "_DECORATION_PINION_RIGHT_SHED_B60x_PART", -- right shed cream pinion
		            StoneGateSetPrefix .. "_DECORATION_PINION_LEFT_SHED_D60x_PART", -- left shed full wooden pinion
		            StoneGateSetPrefix .. "_DECORATION_PINION_RIGHT_SHED_D60x_PART", -- right shed full wooden pinion
		            StoneGateSetPrefix .. "_DECORATION_PINION_LEFT_SHED_C60x_PART", -- left pinion for shed roof
		            StoneGateSetPrefix .. "_DECORATION_PINION_RIGHT_SHED_C60x_PART", -- right pinion for shed roof
                        }
                },
		{
			Name = StoneGateSetPrefix .. "_HOARDING_PARTSETLIST_NAME",
	                BuildingPartList = {
		            StoneGateSetPrefix .. "_HOARDING_S2L0R0_PART",
		            StoneGateSetPrefix .. "_HOARDING_S2L0R1_PART",
		            StoneGateSetPrefix .. "_HOARDING_S2L1R0_PART",
		            StoneGateSetPrefix .. "_HOARDING_S2L1R1_PART",
		            StoneGateSetPrefix .. "_EXTENSION_S2L0R0_PART",
		            StoneGateSetPrefix .. "_HOARDING_S3L0R0_PART",
		            StoneGateSetPrefix .. "_HOARDING_S3L0R1_PART",
		            StoneGateSetPrefix .. "_HOARDING_S3L1R0_PART",
		            StoneGateSetPrefix .. "_HOARDING_S3L1R1_PART",
		            StoneGateSetPrefix .. "_EXTENSION_S3L0R0_PART"
                        }
                },
		{
			Name = StoneGateSetPrefix .. "_MACHICOLATION_PARTSETLIST_NAME",
	                BuildingPartList = {
		            StoneGateSetPrefix .. "_MACHICOLATION_KEEP_C_PART",
		            StoneGateSetPrefix .. "_MACHICOLATION_KEEP_C_P_PART",
		            StoneGateSetPrefix .. "_MACHICOLATION_CRENATION34_PART",
		            StoneGateSetPrefix .. "_MACHICOLATION_CRENATION40R_PART",
		            StoneGateSetPrefix .. "_MACHICOLATION_CRENATION40L_PART",
		            StoneGateSetPrefix .. "_MACHICOLATION_CRENATION50_PART",
		            StoneGateSetPrefix .. "_MACHICOLATION_KEEP_ROOF_C_PART",
		            StoneGateSetPrefix .. "_MACHICOLATION_MAIN_D_PART",
		            StoneGateSetPrefix .. "_MACHICOLATION_MAIN_D_P_PART",
		            StoneGateSetPrefix .. "_MACHICOLATION_CRENATION54_PART",
		            StoneGateSetPrefix .. "_MACHICOLATION_CRENATION60R_PART",
		            StoneGateSetPrefix .. "_MACHICOLATION_CRENATION60L_PART",
		            StoneGateSetPrefix .. "_MACHICOLATION_CRENATION70_PART",
		            StoneGateSetPrefix .. "_MACHICOLATION_MAIN_ROOF_D_PART"
		        }
                },
		{
			Name = StoneGateSetPrefix .. "_SST_PARTSETLIST_NAME",
	                BuildingPartList = {
		            StoneGateSetPrefix .. "_SST_ROOT_PART",
		            StoneGateSetPrefix .. "_SST_ROOTP_PART",
		            StoneGateSetPrefix .. "_SST_ROOTGATE_PART",
		            StoneGateSetPrefix .. "_SST_ROOTGATEP_PART",
		            StoneGateSetPrefix .. "_SST_ROOTGATE2_PART",
		            StoneGateSetPrefix .. "_SST_ROOTGATE2P_PART",
		            StoneGateSetPrefix .. "_SST_ROOF_A45_PART", -- Closed roof
		            StoneGateSetPrefix .. "_SST_ROOF_B45_PART",  -- 1 side opened roof
		            StoneGateSetPrefix .. "_SST_ROOF_D45_PART",  -- 2 opposite sides opened
		            StoneGateSetPrefix .. "_SST_ROOF_E45_PART",  -- 2 adjacent sides opened
		            StoneGateSetPrefix .. "_SST_ROOF_F45_PART",  -- 3 sides opened
		            StoneGateSetPrefix .. "_SST_ROOF_G45_PART",  -- all sides opened
		            StoneGateSetPrefix .. "_SST_ROOF_H45_PART",  -- extension
		            StoneGateSetPrefix .. "_SST_ROOF_I45_PART",  -- extension
		            StoneGateSetPrefix .. "_DECORATION_PINION_E_PART", -- small simple pinion
		            StoneGateSetPrefix .. "_DECORATION_PINION_H_PART", -- small simple stone pinion
		            StoneGateSetPrefix .. "_DECORATION_PINION_J_PART", -- small simple full wooden pinion
		            StoneGateSetPrefix .. "_DECORATION_PINION_F_PART", -- small simple pinion
		            StoneGateSetPrefix .. "_SST_ROOF_J45_PART",  -- shed roof wit 3 sides opened
		            StoneGateSetPrefix .. "_SST_ROOF_K45_PART",  -- shed roof wit 2 adjacent sides opened
		            StoneGateSetPrefix .. "_SST_ROOF_L45_PART",  -- shed roof extension
		            StoneGateSetPrefix .. "_DECORATION_PINION_SHED_E_PART", -- small shed simple pinion
		            StoneGateSetPrefix .. "_DECORATION_PINION_SHED_H_PART", -- small shed simple stone pinion
		            StoneGateSetPrefix .. "_DECORATION_PINION_SHED_J_PART", -- small shed simple full wooden pinion
		            StoneGateSetPrefix .. "_DECORATION_PINION_SHED_F_PART", -- small shed simple pinion
		            StoneGateSetPrefix .. "_SST_RAMPART_A_PART",  -- Close rampart
		            StoneGateSetPrefix .. "_SST_RAMPART_B_PART",   -- 1 side opened rampart
		            StoneGateSetPrefix .. "_SST_RAMPART_C_PART",   -- 1 side closed rampart
		            StoneGateSetPrefix .. "_HOARDING_S1_A_PART",
		            StoneGateSetPrefix .. "_HOARDING_S1_B_PART",
		            StoneGateSetPrefix .. "_HOARDING_S1_C_PART",
		            StoneGateSetPrefix .. "_HOARDING_S1_D_PART",
                        }
                },
		{
			Name = StoneGateSetPrefix .. "_SST_POINTED_PARTSETLIST_NAME",
	                BuildingPartList = {
		            StoneGateSetPrefix .. "_SST_POINTED_ROOF_A_PART", -- 2 opposite sides opened
		            StoneGateSetPrefix .. "_SST_POINTED_ROOF_B_PART", -- 1 side opened roof
		            StoneGateSetPrefix .. "_SST_POINTED_ROOF_C_PART", -- Closed roof
		            StoneGateSetPrefix .. "_SST_POINTED_ROOF_D_PART", -- 2 adjacent sides opened
		            StoneGateSetPrefix .. "_SST_POINTED_ROOF_G_PART", -- extension
		            StoneGateSetPrefix .. "_SST_POINTED_ROOF_H_PART", -- extension
		            StoneGateSetPrefix .. "_DECORATION_POINTED_PINION_E_PART", -- small pointed pinion
		            StoneGateSetPrefix .. "_DECORATION_POINTED_PINION_H_PART", -- small pointed stone pinion
		            StoneGateSetPrefix .. "_DECORATION_POINTED_PINION_J_PART", -- small pointed full wooden pinion
		            StoneGateSetPrefix .. "_DECORATION_POINTED_PINION_F_PART", -- small pointed pinion
                        }
                },
		{
			Name = StoneGateSetPrefix .. "_SST30_PARTSETLIST_NAME",
	                BuildingPartList = {
		            StoneGateSetPrefix .. "_SST_ROOF_A30_PART", -- Closed roof
		            StoneGateSetPrefix .. "_SST_ROOF_B30_PART",  -- 1 side opened roof
		            StoneGateSetPrefix .. "_SST_ROOF_D30_PART",  -- 2 opposite sides opened
		            StoneGateSetPrefix .. "_SST_ROOF_E30_PART",  -- 2 adjacent sides opened
		            StoneGateSetPrefix .. "_SST_ROOF_F30_PART",  -- 3 sides opened
		            StoneGateSetPrefix .. "_SST_ROOF_G30_PART",  -- all sides opened
		            StoneGateSetPrefix .. "_SST_ROOF_H30_PART",  -- extension
		            StoneGateSetPrefix .. "_SST_ROOF_I30_PART",  -- extension
		            StoneGateSetPrefix .. "_DECORATION_PINION_E30_PART", -- small simple pinion
		            StoneGateSetPrefix .. "_DECORATION_PINION_H30_PART", -- small simple stone pinion
		            StoneGateSetPrefix .. "_DECORATION_PINION_J30_PART", -- small simple full wooden pinion
		            StoneGateSetPrefix .. "_DECORATION_PINION_F30_PART", -- small simple pinion
		            StoneGateSetPrefix .. "_SST_ROOF_J30_PART",  -- shed roof wit 3 sides opened
		            StoneGateSetPrefix .. "_SST_ROOF_K30_PART",  -- shed roof wit 2 adjacent sides opened
		            StoneGateSetPrefix .. "_SST_ROOF_L30_PART",  -- shed roof extension
 		            StoneGateSetPrefix .. "_DECORATION_PINION_SHED_E30_PART", -- small shed simple pinion
		            StoneGateSetPrefix .. "_DECORATION_PINION_SHED_H30_PART", -- small shed simple stone pinion
		            StoneGateSetPrefix .. "_DECORATION_PINION_SHED_J30_PART", -- small shed simple full wooden pinion
		            StoneGateSetPrefix .. "_DECORATION_PINION_SHED_F30_PART", -- small shed simple pinion
                        }
                },
		{
			Name = StoneGateSetPrefix .. "_SST60_PARTSETLIST_NAME",
	                BuildingPartList = {
		            StoneGateSetPrefix .. "_SST_ROOF_A60_PART", -- Closed roof
		            StoneGateSetPrefix .. "_SST_ROOF_B60_PART",  -- 1 side opened roof
		            StoneGateSetPrefix .. "_SST_ROOF_D60_PART",  -- 2 opposite sides opened
		            StoneGateSetPrefix .. "_SST_ROOF_E60_PART",  -- 2 adjacent sides opened
		            StoneGateSetPrefix .. "_SST_ROOF_F60_PART",  -- 3 sides opened
		            StoneGateSetPrefix .. "_SST_ROOF_G60_PART",  -- all sides opened
		            StoneGateSetPrefix .. "_SST_ROOF_H60_PART",  -- extension
		            StoneGateSetPrefix .. "_SST_ROOF_I60_PART",  -- extension
		            StoneGateSetPrefix .. "_DECORATION_PINION_E60_PART", -- small simple pinion
		            StoneGateSetPrefix .. "_DECORATION_PINION_H60_PART", -- small simple stone pinion
		            StoneGateSetPrefix .. "_DECORATION_PINION_J60_PART", -- small simple full wooden pinion
		            StoneGateSetPrefix .. "_DECORATION_PINION_F60_PART", -- small simple pinion
		            StoneGateSetPrefix .. "_SST_ROOF_J60_PART",  -- shed roof wit 3 sides opened
		            StoneGateSetPrefix .. "_SST_ROOF_K60_PART",  -- shed roof wit 2 adjacent sides opened
		            StoneGateSetPrefix .. "_SST_ROOF_L60_PART",  -- shed roof extension
 		            StoneGateSetPrefix .. "_DECORATION_PINION_SHED_E60_PART", -- small shed simple pinion
		            StoneGateSetPrefix .. "_DECORATION_PINION_SHED_H60_PART", -- small shed simple stone pinion
		            StoneGateSetPrefix .. "_DECORATION_PINION_SHED_J60_PART", -- small shed simple full wooden pinion
		            StoneGateSetPrefix .. "_DECORATION_PINION_SHED_F60_PART", -- small shed simple pinion
                        }
                },
		{
			Name = StoneGateSetPrefix .. "_SST_MACHICOLATION_PARTSETLIST_NAME",
	                BuildingPartList = {
		            StoneGateSetPrefix .. "_MACHICOLATION_SST_RAMPART_A_PART",
		            StoneGateSetPrefix .. "_MACHICOLATION_SST_RAMPART_B_PART",
		            StoneGateSetPrefix .. "_MACHICOLATION_SST_RAMPART_C_PART",
		            StoneGateSetPrefix .. "_MACHICOLATION_SST_RAMPART_D_PART",
		            StoneGateSetPrefix .. "_MACHICOLATION_SST_RAMPART_E_PART",
		            StoneGateSetPrefix .. "_MACHICOLATION_SST_RAMPART_AP_PART",
		            StoneGateSetPrefix .. "_MACHICOLATION_SST_RAMPART_BP_PART",
		            StoneGateSetPrefix .. "_MACHICOLATION_SST_RAMPART_CP_PART",
		            StoneGateSetPrefix .. "_MACHICOLATION_SST_RAMPART_DP_PART",
		            StoneGateSetPrefix .. "_MACHICOLATION_SST_RAMPART_EP_PART",
		            StoneGateSetPrefix .. "_MACHICOLATION_SST_ROOF_A45_PART", -- Closed roof
		            StoneGateSetPrefix .. "_MACHICOLATION_SST_ROOF_B45_PART", -- 1 side opened roof
		            StoneGateSetPrefix .. "_MACHICOLATION_SST_ROOF_C45_PART", -- 2 adjacent sides opened
		            StoneGateSetPrefix .. "_MACHICOLATION_SST_ROOF_D45_PART", -- 2 opposite sides opened
		            StoneGateSetPrefix .. "_MACHICOLATION_SST_ROOF_A30_PART", -- Closed roof
		            StoneGateSetPrefix .. "_MACHICOLATION_SST_ROOF_B30_PART", -- 1 side opened roof
		            StoneGateSetPrefix .. "_MACHICOLATION_SST_ROOF_C30_PART", -- 2 adjacent sides opened
		            StoneGateSetPrefix .. "_MACHICOLATION_SST_ROOF_D30_PART", -- 2 opposite sides opened
		            StoneGateSetPrefix .. "_MACHICOLATION_SST_ROOF_A60_PART", -- Closed roof
		            StoneGateSetPrefix .. "_MACHICOLATION_SST_ROOF_B60_PART", -- 1 side opened roof
		            StoneGateSetPrefix .. "_MACHICOLATION_SST_ROOF_C60_PART", -- 2 adjacent sides opened
		            StoneGateSetPrefix .. "_MACHICOLATION_SST_ROOF_D60_PART", -- 2 opposite sides opened
		            StoneGateSetPrefix .. "_SST_POINTED_ROOF_MA_PART", -- 2 opposite sides opened
		            StoneGateSetPrefix .. "_SST_POINTED_ROOF_MB_PART", -- 1 side opened roof
		            StoneGateSetPrefix .. "_SST_POINTED_ROOF_MC_PART", -- Closed roof
		            StoneGateSetPrefix .. "_SST_POINTED_ROOF_MD_PART", -- 2 adjacent sides opened
                        }
                },
		{
			Name = StoneGateSetPrefix .. "_SST_OTHER_PARTSETLIST_NAME",
	                BuildingPartList = {
		            StoneGateSetPrefix .. "_SST_ROOTSTAIR_PART",
		            StoneGateSetPrefix .. "_SST_ROOTSTAIRP_PART",
		            StoneGateSetPrefix .. "_SST_STAIR_A_PART",   -- stairs with stone floor
		            StoneGateSetPrefix .. "_SST_STAIR_B_PART",   -- stairs with wooden floor
         	            StoneGateSetPrefix .. "_SST_RAMPART_D_PART", -- 1 side for stairs
		            StoneGateSetPrefix .. "_SST_RAMPART_E_PART",  -- 1 side for stairs
		            StoneGateSetPrefix .. "_WFDECORATION_STAIR_RAIL_R_PART",
		            StoneGateSetPrefix .. "_WFDECORATION_STAIR_RAIL_L_PART",
		            StoneGateSetPrefix .. "_SST_BRIDGE1_PART",   -- simple bridge part with stone floor
		            StoneGateSetPrefix .. "_SST_BRIDGE1P_PART",  -- simple bridge part with wooden floor
		            StoneGateSetPrefix .. "_SST_STONE_FLOOR_PART",  -- floor with stone floor
		            StoneGateSetPrefix .. "_SST_STONE_FLOORP_PART", -- floor with wooden floor
		            StoneGateSetPrefix .. "_SST_HALF_ARCH1_PART",-- Small half arch bridge part
		            StoneGateSetPrefix .. "_SST_HALF_ARCH2_PART",-- Large half arch bridge part
		            StoneGateSetPrefix .. "_SST_ROOTHALFWHITE_PART",
		            StoneGateSetPrefix .. "_WFSST_A_PART",
		            StoneGateSetPrefix .. "_WFSST_B_PART",
		            StoneGateSetPrefix .. "_WFSST_C_PART",
		            StoneGateSetPrefix .. "_WFSST_D_PART",
		            StoneGateSetPrefixWhiteFloor .. "_WFSST_A_PART",
		            StoneGateSetPrefixWhiteFloor .. "_WFSST_B_PART",
		            StoneGateSetPrefixWhiteFloor .. "_WFSST_C_PART",
--		            StoneGateSetPrefix .. "_PILLINGS_ROOT_PART", --deprecated
		            StoneGateSetPrefix .. "_PILLINGSA_ROOT_PART",
		            StoneGateSetPrefix .. "_PILLINGSB_ROOT_PART", --stairs
		            StoneGateSetPrefix .. "_PILLINGSB_PART",
-- deprecated		            StoneGateSetPrefix .. "_WFDECORATION_A_PART",
-- deprecated		            StoneGateSetPrefix .. "_WFDECORATION_B_PART",
-- deprecated		            StoneGateSetPrefix .. "_WFDECORATION_C_PART",
		            StoneGateSetPrefix .. "_WFDECORATION_D_PART",
		            StoneGateSetPrefix .. "_WFDECORATION_E_PART",
		            StoneGateSetPrefix .. "_WFDECORATION_F_PART",
		            StoneGateSetPrefix .. "_WFDECORATION_G_PART",
                        }
                },
 		{
			Name = StoneGateSetPrefix .. "_SGATE_PARTSETLIST_NAME",
	                BuildingPartList = {
		            StoneGateSetPrefix .. "_SGATE_ROOT_A_PART",
		            StoneGateSetPrefix .. "_SGATE_ROOT_UPPER_PART",
		            StoneGateSetPrefix .. "_SGATE_EXT_ROOT_PART",
		            StoneGateSetPrefix .. "_SGATE_ROOFA45_PART",
		            StoneGateSetPrefix .. "_SGATE_ROOFA30_PART",
		            StoneGateSetPrefix .. "_SGATE_ROOFA60_PART",
		            StoneGateSetPrefix .. "_SGATE_POINTED_ROOF_A_PART",
		            StoneGateSetPrefix .. "_SGATE_ROOT_AP_PART",
		            StoneGateSetPrefix .. "_SGATE_ROOT_UPPERP_PART",
		            StoneGateSetPrefix .. "_SGATE_EXT_ROOTP_PART",
		            StoneGateSetPrefix .. "_WFSGATE_A_PART",
		            StoneGateSetPrefix .. "_WFSGATE_B_PART",
		            StoneGateSetPrefix .. "_WFSGATE_C_PART",
		            StoneGateSetPrefix .. "_WFSGATE_D_PART",
		            StoneGateSetPrefixWhiteFloor .. "_WFSGATE_A_PART",
		            StoneGateSetPrefixWhiteFloor .. "_WFSGATE_B_PART",
		            StoneGateSetPrefixWhiteFloor .. "_WFSGATE_C_PART",
		            StoneGateSetPrefix .. "_SGATE_RAMPART_A_PART",
		            StoneGateSetPrefix .. "_SGATE_RAMPART_CLOSING_L_PART",
		            StoneGateSetPrefix .. "_SGATE_RAMPART_CLOSING_R_PART",
		            StoneGateSetPrefix .. "_HOARDING_SGATE_D_PART", -- on full rampart
		            StoneGateSetPrefix .. "_HOARDING_SGATE_EXTENSION_PART", -- on full rampart
		            StoneGateSetPrefix .. "_MACHICOLATION_SGATE_RAMPART_C_PART", -- on full rampart, 2 sides, stone floor
		            StoneGateSetPrefix .. "_MACHICOLATION_SGATE_RAMPART_E_PART", -- on full rampart, 1 side, stone floor
		            StoneGateSetPrefix .. "_MACHICOLATION_SGATE_RAMPART_CP_PART", -- on full rampart, 2 sides, wooden floor
		            StoneGateSetPrefix .. "_MACHICOLATION_SGATE_RAMPART_EP_PART", -- on full rampart, 1 side, wooden floor 
		            StoneGateSetPrefix .. "_MACHICOLATION_SGATE_ROOF_D45_PART", -- on full rampart, 2 opposite sides opened
		            StoneGateSetPrefix .. "_MACHICOLATION_SGATE_ROOF_D30_PART", -- on full rampart, 2 opposite sides opened
		            StoneGateSetPrefix .. "_MACHICOLATION_SGATE_ROOF_D60_PART", -- on full rampart, 2 opposite sides opened
		            StoneGateSetPrefix .. "_SGATE_POINTED_ROOF_MA_PART",
--		            StoneGateSetPrefix .. "_SGATE_HALF_ROOF_PART",
--		            StoneGateSetPrefix .. "_SGATE_HALF_ROOFP_PART",
		            StoneGateSetPrefix .. "_SGATE_HALF_ROOF_ROOT_PART",
		            StoneGateSetPrefix .. "_SGATE_HALF_ROOF_ROOT_UPPER_PART",
		            StoneGateSetPrefix .. "_SGATE_HALF_ROOF_EXT_ROOT_PART",
		            StoneGateSetPrefix .. "_SGATE_HALF_ROOF_ROOTP_PART",
		            StoneGateSetPrefix .. "_SGATE_HALF_ROOF_ROOT_UPPERP_PART",
		            StoneGateSetPrefix .. "_SGATE_HALF_ROOF_EXT_ROOTP_PART",
		            StoneGateSetPrefix .. "_HOARDING_SGATE_A_PART", -- over Half-roof
		            StoneGateSetPrefix .. "_SGATE_MACHICOLATION_A_PART", -- over Half-roof, stone floor
		            StoneGateSetPrefix .. "_SGATE_MACHICOLATION_AP_PART", -- over Half-roof, wooden floor
		            StoneGateSetPrefix .. "_SGATE_MACHICOLATION_CLOSING_L_PART",
		            StoneGateSetPrefix .. "_SGATE_MACHICOLATION_CLOSING_R_PART",
		            StoneGateSetPrefix .. "_SGATE_MACHICOLATION_WOODEN_ROOF_A_PART", -- over Half-roof
		            StoneGateSetPrefix .. "_SGATE_MACHICOLATION_STONE_ROOF_A_PART"   -- over Half-roof
                        }
                },
		{
			Name = StoneGateSetPrefix .. "_A45_PARTSETLIST_NAME",
	                BuildingPartList = {
		            StoneGateSetPrefix .. "_A45_ROOT_PART",  -- with stone floor
		            StoneGateSetPrefix .. "_A45_ROOTP_PART", -- with wooden floor
		            StoneGateSetPrefix .. "_A45_ROOF45_PART",
		            StoneGateSetPrefix .. "_A45_ROOF30_PART",
		            StoneGateSetPrefix .. "_A45_ROOF60_PART",
		            StoneGateSetPrefix .. "_A45_POINTED_ROOF_A_PART",
		            StoneGateSetPrefix .. "_A45_RAMPART_A_PART",
		            StoneGateSetPrefix .. "_HOARDING_A45_D_PART",
		            StoneGateSetPrefix .. "_MACHICOLATION_A45_RAMPART_E_PART", -- on full rampart, 1 side, stone floor
		            StoneGateSetPrefix .. "_MACHICOLATION_A45_RAMPART_EP_PART", -- on full rampart, 1 side, wooden floor
		            StoneGateSetPrefix .. "_MACHICOLATION_A45_ROOF_E45_PART",
		            StoneGateSetPrefix .. "_MACHICOLATION_A45_ROOF_E30_PART",
		            StoneGateSetPrefix .. "_MACHICOLATION_A45_ROOF_E60_PART",
		            StoneGateSetPrefix .. "_A45_POINTED_ROOF_MA_PART",
		            StoneGateSetPrefix .. "_WFA45_A_PART",
		            StoneGateSetPrefix .. "_WFA45_B_PART",
		            StoneGateSetPrefix .. "_WFA45_C_PART",
		            StoneGateSetPrefix .. "_WFA45_D_PART",
		            StoneGateSetPrefixWhiteFloor .. "_WFA45_A_PART",
		            StoneGateSetPrefixWhiteFloor .. "_WFA45_B_PART",
		            StoneGateSetPrefixWhiteFloor .. "_WFA45_C_PART",
                        }
                },
		{
			Name = StoneGateSetPrefix .. "_OTOWER_PARTSETLIST_NAME",
	                BuildingPartList = {
		            StoneGateSetPrefix .. "_OTOWER_ROOT_PART",
		            StoneGateSetPrefix .. "_OTOWER_ROOTB_PART",
		            StoneGateSetPrefix .. "_OTOWER_ROOTHALFWHITE_PART",
		            StoneGateSetPrefix .. "_OTOWER_ROOF_PART",
		            StoneGateSetPrefix .. "_OTOWER_ROOF30_PART",
		            StoneGateSetPrefix .. "_OTOWER_ROOF60_PART",
		            StoneGateSetPrefix .. "_OTOWER_POINTED_ROOF_B_PART",
		            StoneGateSetPrefix .. "_OTOWER_RAMPART_PART", -- all sides
		            StoneGateSetPrefix .. "_OTOWER_RAMPART_B_PART", -- one side
		            StoneGateSetPrefix .. "_OTOWER_RAMPART_C_PART", -- one side open
		            StoneGateSetPrefix .. "_OTOWER_HOARDING_PART",
		            StoneGateSetPrefix .. "_OTOWER_HOARDING_EXT_PART",
		            StoneGateSetPrefix .. "_OTOWER_MACHICOLATION_PART",
		            StoneGateSetPrefix .. "_OTOWER_MACHICOLATION_B_PART",
		            StoneGateSetPrefix .. "_OTOWER_MACHICOLATION_ROOF_PART",
		            StoneGateSetPrefix .. "_WFOCTOGONAL_A_PART",
		            StoneGateSetPrefix .. "_WFOCTOGONAL_B_PART",
		            StoneGateSetPrefix .. "_WFOCTOGONAL_C_PART",
		            StoneGateSetPrefix .. "_WFOCTOGONAL_D_PART",
		            StoneGateSetPrefixWhiteFloor .. "_WFOCTOGONAL_A_PART",
		            StoneGateSetPrefixWhiteFloor .. "_WFOCTOGONAL_B_PART",
		            StoneGateSetPrefixWhiteFloor .. "_WFOCTOGONAL_C_PART",
                        }
                },
		{
			Name = StoneGateSetPrefix .. "_CIRCULAR_PARTSETLIST_NAME",
	                BuildingPartList = {
		            StoneGateSetPrefix .. "_CIRCULAR_ROOT_PART",  -- with stone floor
		            StoneGateSetPrefix .. "_CIRCULAR_ROOTB_PART", -- with wooden floor
		            StoneGateSetPrefix .. "_CIRCULAR_ROOTHALFWHITE_PART",  -- basement and half-timbered
		            StoneGateSetPrefix .. "_CIRCULAR_ROOF_PART",
		            StoneGateSetPrefix .. "_CIRCULAR_ROOF30_PART",
		            StoneGateSetPrefix .. "_CIRCULAR_ROOF60_PART",
		            StoneGateSetPrefix .. "_CIRCULAR_POINTED_ROOF_B_PART",
		            StoneGateSetPrefix .. "_CIRCULAR_RAMPART_PART", -- all sides
		            StoneGateSetPrefix .. "_CIRCULAR_RAMPART_B_PART", -- one side
		            StoneGateSetPrefix .. "_CIRCULAR_MACHICOLATION_A_PART",
		            StoneGateSetPrefix .. "_CIRCULAR_MACHICOLATION_B_PART",
		            StoneGateSetPrefix .. "_CIRCULAR_MACHICOLATION_PLATFORM_PART",
		            StoneGateSetPrefix .. "_CIRCULAR_HOARDING_PART",
		            StoneGateSetPrefix .. "_WFCIRCULAR_A_PART",
		            StoneGateSetPrefix .. "_WFCIRCULAR_B_PART",
		            StoneGateSetPrefix .. "_WFCIRCULAR_C_PART",
		            StoneGateSetPrefix .. "_WFCIRCULAR_D_PART",
		            StoneGateSetPrefixWhiteFloor .. "_WFCIRCULAR_A_PART",
		            StoneGateSetPrefixWhiteFloor .. "_WFCIRCULAR_B_PART",
		            StoneGateSetPrefixWhiteFloor .. "_WFCIRCULAR_C_PART",
                        }
                },
		{
			Name = StoneGateSetPrefix .. "_SCT_PARTSETLIST_NAME",
	                BuildingPartList = {
		            StoneGateSetPrefix .. "_SCT_ROOT_PART",  -- with stone floor
		            StoneGateSetPrefix .. "_SCT_ROOTP_PART", -- with wooden floor
		            StoneGateSetPrefix .. "_SCT_ROOF45_PART", -- standard roof
		            StoneGateSetPrefix .. "_SCT_ROOF30_PART", -- standard roof
		            StoneGateSetPrefix .. "_SCT_ROOF60_PART", -- standard roof
		            StoneGateSetPrefix .. "_SCT_STONE_FLOOR_BASE_PART", -- stone floor base with stone ground
		            StoneGateSetPrefix .. "_SCT_STONE_FLOOR_BASEP_PART", -- stone floor base with wooden ground
		            StoneGateSetPrefix .. "_SCT_STONE_FLOOR_PART", -- stone floor with stone ground
		            StoneGateSetPrefix .. "_SCT_STONE_FLOORP_PART", -- stone floor with wooden ground
		            StoneGateSetPrefix .. "_SCT_POINTED_ROOF_B_PART",
		            StoneGateSetPrefix .. "_SCT_RAMPART_A_PART", -- full circle
		            StoneGateSetPrefix .. "_SCT_RAMPART_B_PART", -- half circle
		            StoneGateSetPrefix .. "_MACHICOLATION_SCT_RAMPART_A_PART",
		            StoneGateSetPrefix .. "_MACHICOLATION_SCT_RAMPART_B_PART",
		            StoneGateSetPrefix .. "_MACHICOLATION_SCT_RAMPART_AP_PART",
		            StoneGateSetPrefix .. "_MACHICOLATION_SCT_RAMPART_BP_PART",
		            StoneGateSetPrefix .. "_MACHICOLATION_SCT_ROOF_A45_PART", -- Closed roof
		            StoneGateSetPrefix .. "_MACHICOLATION_SCT_ROOF_A30_PART", -- Closed roof
		            StoneGateSetPrefix .. "_MACHICOLATION_SCT_ROOF_A60_PART", -- Closed roof
		            StoneGateSetPrefix .. "_SCT_POINTED_ROOF_MB_PART",
		            StoneGateSetPrefix .. "_WFSCT_A_PART",
		            StoneGateSetPrefix .. "_WFSCT_B_PART",
		            StoneGateSetPrefix .. "_WFSCT_C_PART",
		            StoneGateSetPrefix .. "_WFSCT_D_PART",
		            StoneGateSetPrefixWhiteFloor .. "_WFSCT_A_PART",
		            StoneGateSetPrefixWhiteFloor .. "_WFSCT_B_PART",
		            StoneGateSetPrefixWhiteFloor .. "_WFSCT_C_PART",
                        }
                },
		{
			Name = StoneGateSetPrefix .. "_ENTRANCE_PARTSETLIST_NAME",
	                BuildingPartList = {
 		            CommonDoorPrefix .. "_ENTRANCE_DOOR_A_PART",
  		            CommonDoorPrefix .. "_ENTRANCE_DOOR_B_PART",
  		            CommonDoorPrefix .. "_ENTRANCE_WOODEN_DOOR_C_PART",
  		            CommonDoorPrefix .. "_ENTRANCE_WOODEN_DOOR_D_PART",
  		            CommonDoorPrefix .. "_ENTRANCE_WOODEN_DOOR_E_PART",
		            CommonDoorPrefix .. "_ENTRANCE_WOODEN_AMERICAN_DOOR_1_PART",
		            StoneGateSetPrefix .. "_SST_STAIR_C_PART",   -- stairs foundation with stone floor
		            StoneGateSetPrefix .. "_SST_STAIR_D_PART"   -- stairs foundation with wooden floor
                       }
                },
                {
			Name = StoneGateSetPrefix .. "_BRIDGE_PARTSETLIST_NAME",
	                BuildingPartList = {
		            StoneGateSetPrefix .. "_DRAW_BRIDGE_A_CORE_PART",
		            StoneGateSetPrefix .. "_DRAW_BRIDGE_B_CORE_PART",
		            StoneGateSetPrefix .. "_DRAW_BRIDGE_C_CORE_PART",
		            StoneGateSetPrefix .. "_DRAW_BRIDGE_PORTCULLIS_PART"
                        }
                },
		{
			Name = StoneGateSetPrefix .. "_DECORATION_PARTSETLIST_NAME",
	                BuildingPartList = {
                            -- the minor attach point are upside-down related to vanilla in this version, so it is planned for a V8
                            -- "BUILDING_PART_GATE_WALL_BANNER",
		            CommonWindowPrefix .. "_CORNER_ROOT_PART",
		            CommonWindowPrefix .. "_DECORATION_SFENETRE_PART",
		            CommonWindowPrefix .. "_DECORATION_LFENETRE_PART",
		            CommonWindowPrefix .. "_DECORATION_PFENETRE_PART",
		            CommonWindowPrefix .. "_DECORATION_ARROWSLIT_PART",
		            CommonWindowPrefix .. "_DECORATION_BALCONY_PART",
		            StoneGateSetPrefix .. "_DECORATION_DOOR_A_PART",
		            StoneGateSetPrefix .. "_DECORATION_DOOR_B_PART",
		            StoneGateSetPrefix .. "_DECORATION_DOOR_MA_PART",
		            StoneGateSetPrefix .. "_DECORATION_DOOR_MB_PART",
		            CommonWindowPrefix .. "_DECORATION_BUTTRESS_PART",
-- deprecated		            StoneGateSetPrefix .. "_DECORATION_CHIMNEY_BASE_PART",
		            CommonWindowPrefix .. "_DECORATION_CHIMNEY_PART",
-- deprecated		            StoneGateSetPrefix .. "_DECORATION_POINTED_ROOF_BASE_PART",
		            CommonWindowPrefix .. "_DECORATION_LUCARNE_PART",
		            CommonWindowPrefix .. "_DECORATION_MEDIUM_LUCARNE_PART",
		            CommonWindowPrefix .. "_DECORATION_LARGE_LUCARNE_PART",
		            CommonWindowPrefix .. "_DECORATION_LUCARNE_WHITE_PART",
		            CommonWindowPrefix .. "_DECORATION_MEDIUM_LUCARNE_WHITE_PART",
		            CommonWindowPrefix .. "_DECORATION_LARGE_LUCARNE_WHITE_PART",
		            CommonWindowPrefix .. "_DECORATION_TURRET_PART",
		            CommonWindowPrefix .. "_DECORATION_STONE_ROUND_WINDOW_PART",
		            StoneGateSetPrefix .. "_POLE_FLAG_RED_ROOT_PART",
		            StoneGateSetPrefix .. "_POLE_FLAG_BLUE_ROOT_PART",
		            StoneGateSetPrefix .. "_POLE_FLAG_GREEN_ROOT_PART",
		            StoneGateSetPrefix .. "_POLE_FLAG_PURPLE_ROOT_PART",
		            StoneGateSetPrefix .. "_POLE_FLAG_ORANGE_ROOT_PART",
		            StoneGateSetPrefix .. "_POLE_FLAG_TURQUOISE_ROOT_PART",
		            CommonWindowPrefix .. "_DECORATION_FINIAL1_PART",
		            CommonWindowPrefix .. "_DECORATION_FINIAL2_PART",
		            CommonWindowPrefix .. "_DECORATION_FINIAL3_PART",
		            CommonWindowPrefix .. "_DECORATION_STAINED_GLASS_WINDOW_1_PART",
		            CommonWindowPrefix .. "_DECORATION_STAINED_GLASS_1_PART",
		            CommonWindowPrefix .. "_DECORATION_STAINED_GLASS_2_PART",
		            CommonWindowPrefix .. "_DECORATION_STAINED_GLASS_3_PART",
		            CommonWindowPrefix .. "_DECORATION_STAINED_GLASS_4_PART",
		            CommonWindowPrefix .. "_DECORATION_STAINED_GLASS_8_PART",
		            CommonWindowPrefix .. "_DECORATION_SPLENDOR_2_PART",
		            CommonWindowPrefix .. "_DECORATION_P_STAINED_GLASS_1_PART",
		            CommonWindowPrefix .. "_DECORATION_STAINED_GLASS_TALL_1_PART",
		            CommonWindowPrefix .. "_DECORATION_STAINED_GLASS_TALL_2_PART",
		            CommonWindowPrefix .. "_DECORATION_WOODEN_WINDOW_1_PART",
		            CommonWindowPrefix .. "_DECORATION_WOODEN_WINDOW_18_PART",
		            CommonWindowPrefix .. "_DECORATION_WOODEN_WINDOW_3_PART",
		            CommonWindowPrefix .. "_DECORATION_WOODEN_WINDOW_9_PART",
		            CommonWindowPrefix .. "_DECORATION_WOODEN_WINDOW_7_PART",
		            CommonWindowPrefix .. "_DECORATION_WOODEN_WINDOW_8_PART",
		            CommonWindowPrefix .. "_DECORATION_WOODEN_LARGE_WINDOW_PART",
		            CommonWindowPrefix .. "_DECORATION_WOODEN_POINTED_WINDOW_1_PART",
		            CommonWindowPrefix .. "_DECORATION_WOODEN_ROUND_WINDOW_PART",
		            CommonWindowPrefix .. "_DECORATION_WOODEN_AMERICAN_WINDOW_1_PART",
                        }
                },
    }
end

function checkVersion(_mod, _modName, _name, _id, _minimalVersion)
    if (foundation.getModVersion == nil) then
        _mod:logError(_modName .. " Unknown mod version")
        return false
    end
    if not foundation.isModEnabled(_id) then
        _mod:logError(_modName .. " " .. _name .. " disabled")
        return false
    end
    if not foundation.isModLoaded(_id) then
        _mod:logWarning(_modName .. " Up the position of " .. _name .. " in the mod list of your game")
        return false
    end
    local _myVersion = foundation.getModVersion(_id)
    _mod:msgBox(_modName .. " " .. _name .. " Current version : " .. _myVersion)
    if version.cmp(_myVersion, _minimalVersion) < 0 then
        _mod:logWarning(_modName .. " Please, load at least the version " .. _minimalVersion .. " of " .. _name)
        return false
    end
    return true
end

-- Set the sandbox option
function difficultyLevel(_mod, _modName)
    if foundation.isModEnabled("8f186d4a-7b5d-4b8a-b959-43bd254ca95b") then
        _mod:log("Hello World: " .. _modName .. " sandbox mode.")
        return 0
    end
    _mod:log("Hello World: " .. _modName .. " difficulty level low by default")
    return 1
end

--------------------------------------------------------------------------
function computeElevation(_self, _initialPosition, _flagList)
    local _flags = 0
    for i, flag in ipairs(_flagList) do
        _flags = bit.bor(_flags, bit.lshift(1, flag:toNumber()))
    end
    if _flags == 0 then
         _CommonFunctions:logWarning("computeElevation: _flagList empty")
         return _initialPosition[2]
    end 
    local raycastResult = {}

    -- Raycast from the building position + Y = 100
    -- to building position - y = 100
    -- only on objects with a WATER flag
    local FromPosition = { _initialPosition[1], _initialPosition[2]+100, _initialPosition[3] }
    local ToPosition = { _initialPosition[1], _initialPosition[2]-100, _initialPosition[3] }
    
    if not _self:getLevel():rayCast(FromPosition, ToPosition, raycastResult, _flags) then
         _CommonFunctions:logWarning("computeElevation: not any flag found " .. tostring(_flagList))
         return nil
    end
    return raycastResult["Position"][2] 
end


